# pylint: disable=missing-module-docstring
from setuptools import setup
from setuptools.command.install import install


class InstallWithCompile(install):
    """Compile MO files on install"""

    def run(self):
        # pylint: disable=import-outside-toplevel
        from babel.messages.frontend import compile_catalog

        compiler = compile_catalog(self.distribution)
        option_dict = self.distribution.get_option_dict("compile_catalog")
        compiler.domain = [option_dict["domain"][1]]
        compiler.directory = option_dict["directory"][1]
        compiler.run()
        super().run()


setup(
    name="eeauthentic2",
    version="1.2.0",
    packages=[
        "eeauthentic2",
    ],
    package_data={
        "eeauthentic2": [
            "locales/eeauthentic2.pot",
            "locales/*/LC_MESSAGES/eeauthentic2.po",
            "locales/*/LC_MESSAGES/eeauthentic2.mo",
            "static/**",
            "templates/**",
        ],
    },
    url="https://gitlab.easter-eggs.com/ee/eeauthentic2",
    license="GPL3",
    author="Benjamin Renard",
    author_email="brenard@easter-eggs.com",
    description="Easter-eggs Authentic2 addons",
    long_description="This package provide all Easter-eggs's Authentic2 addons",
    install_requires=[
        "authentic2",
        "zxcvbn",
    ],
    message_extractors={
        "eeauthentic2": [
            ("**.py", "python", None),
        ]
    },
    setup_requires=[
        "babel",
    ],
    cmdclass={
        "install": InstallWithCompile,
    },
)
